=============================
Backup/Restore and DR service
=============================

.. toctree::
   :maxdepth: 2

   get_started
   install
   verify
   next-steps
   api_routes
   metadata_structure
   client_structure
   api_documents
   known_issues


This chapter assumes a working setup of OpenStack following the
`OpenStack Installation Tutorial
<https://docs.openstack.org/project-install-guide/ocata/>`_.